Name:           jinput
Version:        2.0.9
Release:        2%{?dist}
Summary:        Java Game Controller API

License:        BSD
URL:            https://github.com/jinput/jinput
Source0:        https://github.com/jinput/jinput/archive/%{version}/%{name}-%{version}.tar.gz
# Fedora-specific patch: will not be sent upstream.  Remove dependencies on
# Windows and OSX code, and fix build issues with the AWT plugin.
Patch0:         001_jinput_build.patch
# Fedora-specific patch: will not be sent upstream.  Do not strip the native
# library.
Patch1:         002_jinput_dontstripso.patch
# Fedora-specific patch: will not be sent upstream.  Load the shared library
# from the Fedora-mandated location.
Patch2:         003_jinput_usesystemload.patch
# Patch from https://java.net/jira/browse/JINPUT-51 to fix a resource leak
Patch4:         005_jinput_leak.patch

BuildRequires:  gcc
BuildRequires:  java-javadoc >= 1:1.6.0
BuildRequires:  jutils-javadoc
BuildRequires:  maven-local
BuildRequires:  mvn(net.java.jutils:jutils)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)

%description
jinput is an implementation of an API for game controller discovery and
polled input.  It is part of a suite of open-source technologies
initiated by the Game Technology Group at Sun Microsystems with the
intention of making the development of high performance games in Java a
reality.  The API itself is pure Java and presents a platform-neutral,
completely portable model of controller discovery and polling.  It can
handle arbitrary controllers and returns both human and machine
understandable descriptions of the inputs available.

%package javadoc
Summary:        Javadocs for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       jutils-javadoc
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%autosetup -p0

# Use Fedora's CFLAGS and LDFLAGS
sed -i "s|-O2 -Wall|$RPM_OPT_FLAGS|;s|-shared|& $RPM_LD_FLAGS|" \
    plugins/linux/build.xml

# Remove unnecessary maven plugins
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin -r :maven-nativedependencies-plugin

# The examples have a jar (rather than pom) dependency on the main project
%pom_xpath_remove pom:project/pom:dependencies/pom:dependency/pom:type \
  examples/pom.xml

# The native plugin is included
%mvn_package net.java.jinput:linux-plugin::natives-linux:%{version}-SNAPSHOT

%build
# Get the latest definitions from <linux/input-event-codes.h>
gawk -f plugins/linux/src/main/native/getDefinitions \
  %{_includedir}/linux/input.h \
  %{_includedir}/linux/input-event-codes.h \
  > plugins/linux/src/main/java/net/java/games/input/NativeDefinitions.java

# Build
%mvn_build

%install
%mvn_install

# jni
install -Dp -m 755 plugins/linux/target/natives/libjinput*.so \
    %{buildroot}%{_libdir}/%{name}/libjinput.so
ln -s ../../..%{_jnidir}/%{name}/%{name}.jar %{buildroot}%{_libdir}/%{name}/

%files -f .mfiles
%doc README.md
%{_libdir}/%{name}/

%files javadoc -f .mfiles-javadoc

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Jun 28 2018 Jerry James <loganjerry@gmail.com> - 2.0.9-1
- New upstream release
- Build with maven instead of ant

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.7-12.20170607git.294629a
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Nov 14 2017 Jerry James <loganjerry@gmail.com> - 2.0.7-11.20170607git.294629a
- Fix broken symlink (bz 1513092)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.7-10.20170607git.294629a
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Sat Jul 29 2017 Jerry James <loganjerry@gmail.com> - 2.0.7-9.20170607git.294629a
- Update to latest git snapshot
- Replace add_maven_depmap with mvn_artifact

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.7-8.20160519git.b813d55
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.7-7.20160519git.b813d55
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon May 23 2016 Jerry James <loganjerry@gmail.com> - 2.0.7-6.20160519git.b813d55
- Switch to github repository
- Drop upstreamed usage bits patch

* Thu Feb  4 2016 Jerry James <loganjerry@gmail.com> - 2.0.7-5.20140526svn
- Definitions now split between linux/input.h and linux/input-event-codes.h
- Build for Java 1.6 instead of the deprecated 1.5
- Do not rebuild everything in the %%check script

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.7-5.20140526svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.7-4.20140526svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 29 2015 Michal Srb <msrb@redhat.com> - 2.0.7-3.20140526svn
- Fix FTBFS (unknown option to `s')

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.7-2.20140526svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jun 23 2014 Jerry James <loganjerry@gmail.com> - 2.0.7-1.20140526svn
- New upstream release

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-10.20130309svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Mar 29 2014 Jerry James <loganjerry@gmail.com> - 2.0.6-9.20130309svn
- Replace @API_VERSION@ and @BUILD_NUMBER@ in net.java.games.input.Version

* Mon Mar 17 2014 Jerry James <loganjerry@gmail.com> - 2.0.6-8.20130309svn
- Fix 003_jinput_usesystemload.patch to always load the so correctly

* Mon Feb 24 2014 Jerry James <loganjerry@gmail.com> - 2.0.6-7.20130309svn
- Require java-headless instead of java (bz 1068289)
- Add 005_jinput_leak.patch and 006_jinput_java5.patch
- Link the plugin with Fedora LDFLAGS
- Preserve timestamp when updating the POMs
- Prevent jutils.jar from being included in jinput.jar

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-6.20130309svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar 11 2013 Jerry James <loganjerry@gmail.com> - 2.0.6-5.20130309svn
- Update to latest subversion snapshot for support for more controller keys

* Thu Mar  7 2013 Jerry James <loganjerry@gmail.com> - 2.0.6-4.20130225svn
- Update to latest subversion snapshot
- Patch the POM to exclude dependencies on the Windows and OSX plugins

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-3.20110801svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-2.20110801svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Feb  2 2012 Jerry James <loganjerry@gmail.com> - 2.0.6-1.20110801svn
- Add patch for missing USAGE bits in the Linux kernel
- Don't build the OSX plugin
- Combine javadocs into one place and fix broken links

* Tue Jul 19 2011 Guido Grazioli <guido.grazioli@gmail.com> - 2.0.6-1.20110719svn
- Initial packaging
